@@ -389,37 +389,37 @@
 
                 (c-flatflat . ,(ly:make-pitch -1 0 DOUBLE-FLAT))
                 (c-flat . ,(ly:make-pitch -1 0 FLAT))
-                (c . ,(ly:make-pitch -1 0 NATURAL))
+                (c-natural . ,(ly:make-pitch -1 0 NATURAL))
                 (c-sharp . ,(ly:make-pitch -1 0 SHARP))
                 (c-sharpsharp . ,(ly:make-pitch -1 0 DOUBLE-SHARP))
                 (d-flatflat . ,(ly:make-pitch -1 1 DOUBLE-FLAT))
                 (d-flat . ,(ly:make-pitch -1 1 FLAT))
-                (d . ,(ly:make-pitch -1 1 NATURAL))
+                (d-natural . ,(ly:make-pitch -1 1 NATURAL))
                 (d-sharp . ,(ly:make-pitch -1 1 SHARP))
                 (d-sharpsharp . ,(ly:make-pitch -1 1 DOUBLE-SHARP))
                 (e-flatflat . ,(ly:make-pitch -1 2 DOUBLE-FLAT))
                 (e-flat . ,(ly:make-pitch -1 2 FLAT))
-                (e . ,(ly:make-pitch -1 2 NATURAL))
+                (e-natural . ,(ly:make-pitch -1 2 NATURAL))
                 (e-sharp . ,(ly:make-pitch -1 2 SHARP))
                 (e-sharpsharp . ,(ly:make-pitch -1 2 DOUBLE-SHARP))
                 (f-flatflat . ,(ly:make-pitch -1 3 DOUBLE-FLAT))
                 (f-flat . ,(ly:make-pitch -1 3 FLAT))
-                (f . ,(ly:make-pitch -1 3 NATURAL))
+                (f-natural . ,(ly:make-pitch -1 3 NATURAL))
                 (f-sharp . ,(ly:make-pitch -1 3 SHARP))
                 (f-sharpsharp . ,(ly:make-pitch -1 3 DOUBLE-SHARP))
                 (g-flatflat . ,(ly:make-pitch -1 4 DOUBLE-FLAT))
                 (g-flat . ,(ly:make-pitch -1 4 FLAT))
-                (g . ,(ly:make-pitch -1 4 NATURAL))
+                (g-natural . ,(ly:make-pitch -1 4 NATURAL))
                 (g-sharp . ,(ly:make-pitch -1 4 SHARP))
                 (g-sharpsharp . ,(ly:make-pitch -1 4 DOUBLE-SHARP))
                 (a-flatflat . ,(ly:make-pitch -1 5 DOUBLE-FLAT))
                 (a-flat . ,(ly:make-pitch -1 5 FLAT))
-                (a . ,(ly:make-pitch -1 5 NATURAL))
+                (a-natural . ,(ly:make-pitch -1 5 NATURAL))
                 (a-sharp . ,(ly:make-pitch -1 5 SHARP))
                 (a-sharpsharp . ,(ly:make-pitch -1 5 DOUBLE-SHARP))
                 (b-flatflat . ,(ly:make-pitch -1 6 DOUBLE-FLAT))
                 (b-flat . ,(ly:make-pitch -1 6 FLAT))
-                (b . ,(ly:make-pitch -1 6 NATURAL))
+                (b-natural . ,(ly:make-pitch -1 6 NATURAL))
                 (b-sharp . ,(ly:make-pitch -1 6 SHARP))
                 (b-sharpsharp . ,(ly:make-pitch -1 6 DOUBLE-SHARP))
                 ))
